C PARAM.H: PARAMETERS, CONSTANTS AND ARRAYS USED IN 

C --------------------------------------------------------
C MAXSZ: SIZE OF ARRAYS IN PROGRAM
C --------------------------------------------------------
      INTEGER MAXSZ
      PARAMETER (MAXSZ=3000)

C --------------------------------------------------------
C FLAGS AND VARIABLES RELATED TO I/O 
C STORED IN COMMON ARRAY 'INPUTS'
C --------------------------------------------------------
      INTEGER QHELP,QIN,QOUT,QREF,QSCREEN,QLOCAL,QGLOBAL,QVERBOS
      INTEGER QEXCL, QCURVES,QNOGLOB
      CHARACTER*120 INFILE, OUTFILE
      DOUBLE PRECISION REF
      COMMON/INPUTS/QHELP,QIN,INFILE,QOUT,OUTFILE,
     *          QREF,REF,QSCREEN,QLOCAL,QGLOBAL,QVERBOS,QEXCL,
     *		QCURVES,QNOGLOB

C --------------------------------------------------------
C VARIABLES RELATED TO I/O OF NUCLEIC ACID PARAMETERS.
C NUMSTEP: NUMBER OF BP STEPS; INDEX TO PARAMETER ARRAYS
C GTILT, GROLL, GTWIST: GLOBAL TILT, ROLL AND TWIST 
C		(AS DEFINED BY CURVES FROM R. LAVERY)
C LTILT, LROLL, LTWIST: LOCAL TILT, ROLL AND TWIST
C               (AS DEFINED BY CURVES FROM R. LAVERY);  
C NUCLEIC ACID PARAMETERS LOADED THROUGH NON-CURVES INPUT WILL BE 
C	LOADED INTO LTILT, LROLL, LTWIST BY DEFAULT
C --------------------------------------------------------

      INTEGER NUMSTEP
      DOUBLE PRECISION GTILT(MAXSZ), GROLL(MAXSZ), GTWIST(MAXSZ)
      DOUBLE PRECISION LTILT(MAXSZ), LROLL(MAXSZ), LTWIST(MAXSZ)
      COMMON/DATA/NUMSTEP,GTILT,GROLL,GTWIST,LTILT,LROLL,LTWIST

C --------------------------------------------------------
C VARIABLES USED TO CALCULATE GLOBAL TILT AND GLOBAL ROLL
C NUMTERM: NUMBER OF TERMS IN THE FINAL SUM; INDEX TO TERMS
C GNTILT, GNROLL, GACCTWS: GLOBAL TILT, ROLL AND ACCUMULATED TWIST TERMS
C LNTILT, LNROLL, LACCTWS: LOCAL TILT, ROLL AND ACCUMULATED TWIST TERMS
C --------------------------------------------------------

      INTEGER NUMTERM
      DOUBLE PRECISION GNTILT(MAXSZ), GNROLL(MAXSZ), GACCTWS(MAXSZ)
      DOUBLE PRECISION LNTILT(MAXSZ), LNROLL(MAXSZ), LACCTWS(MAXSZ)
      COMMON/TERMS/NUMTERM,GNTILT,GNROLL,GACCTWS,
     *          LNTILT,LNROLL,LACCTWS

C --------------------------------------------------------
C VARIABLES USED TO HOLD INDIVIDUAL GLOBAL TILT AND GLOBAL ROLL TERMS
C NUMTERM: DETAILED ABOVE; INDEX TO GTL, ETC. ARRAYS
C GTL, GRL: GLOBAL TILT AND ROLL OF LOCAL TERMS
C	NUCLEIC ACID PARAMETERS LOADED THROUGH NON-CURVES INPUT
C	ARE STORED IN THESE ARRAYS BY DEFAULT
C GTG, GRG: GLOBAL TILT AND ROLL OF GLOBAL TERMS 
C --------------------------------------------------------

      DOUBLE PRECISION GTL(MAXSZ), GRL(MAXSZ), GTG(MAXSZ), GRG(MAXSZ)
      COMMON/RESULTS/GTL,GRL,GTG,GRG

C --------------------------------------------------------
C ARRAYS TO HOLD BP STEP PARAMETERS TO EXCLUDE; CAN BE USED FOR ANALYZING
C  INDIVIDUAL CONTRIBUTIONS TO GLOBAL BEND OR FOR NEGLECTING END EFFECTS
C --------------------------------------------------------

      INTEGER NUMEXCL
      DOUBLE PRECISION EXCLTLT(MAXSZ), EXCLROL(MAXSZ)
      COMMON/TRUNCATED/NUMEXCL,EXCLTLT,EXCLROL

C --------------------------------------------------------
C TEMPORARY ARRAYS TO HOLD TWIST TERMS BEFORE 
C	ACCUMULATION INTO GACCTWS,LACCTWS
C --------------------------------------------------------
      DOUBLE PRECISION GNTWIST(MAXSZ), LNTWIST(MAXSZ)

C --------------------------------------------------------
C TOLERANCE PARAMETER FOR DECODING REF BP PLANE POSITION
C REFERENCE VALUE OF EPSILON IS SET BELOW
C --------------------------------------------------------
      DOUBLE PRECISION EPSILON

C --------------------------------------------------------
C NUMBERS USED IN THE PROGRAM
C --------------------------------------------------------
      DOUBLE PRECISION PI, ONE8TY, ONE, ZERO, NEGONE 

      PI = 3.1415926536D0
      ONE8TY = 180.0D0
      ONE = 1.0D0
      ZERO = 0.0D0
      NEGONE = -1.0D0

      EPSILON = 1.0D-6

